<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Insight Pro
 * @since Travel Insight Pro 1.0
 * @return array An array of default values
 */

function travel_insight_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_insight_pro_default_options = array(

		// Theme Options
		'theme_typography' 				=> 'default',
		'theme_body_typography' 		=> 'default',
		'loader_enable'         		=> false,
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'long_excerpt_length'           => 25,
		'author_box_enable'          	=> true,
		'single_pagination_enable'      => true,
		'single_date_enable'      		=> true,
		'single_category_enable'      	=> true,
		'breadcrumb_enable'         	=> true,
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',
		'copyright_text'           		=> sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'travel-insight-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . __( 'by', 'travel-insight-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_logo_enable'        	=> true,
		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,
		'footer_background' 			=> get_template_directory_uri() . '/assets/uploads/bg-footer.png',
		'site_title_enable'				=> true,
		'site_description_enable'		=> true,
		'site_logo_enable'				=> true,
		'header_social_enable'			=> true,
		'sticky_menu_enable'			=> false,
		'menu_label_enable'				=> true,
		'blog_img_enable'				=> true,
		'blog_date_enable'				=> true,
		'blog_category_enable'			=> true,
		'blog_views_enable'				=> true,
		'theme_color'					=> 'blue',
		'content_width'					=> 'content-width',
		'sortable'						=>  'Featured Slider,Popular Destination,About,Articles,Gallery,Tours,Guide,Call to Action,Counter,Packages',

		// Slider Section
		'slider_enable'					=> true,
		'slider_caption_enable'			=> true,
		'slider_search_enable'			=> true,
		'slider_effect'					=> 'fade',
		'slider_transition_duration'	=> '1000',
		'enable_slider_controls'		=> true,
		'enable_slider_dragable'		=> true,
		'slider_autoplay'				=> true,
		'slider_pause_on_hover'			=> true,
		'slider_wp_travel_filter_enable' => true,
		'slider_layout'					=> 'normal-slider',
		'slider_content_type'			=> 'demo',
		'no_of_slider'					=> 3,

		// Popular Destination
		'popular_destination_enable'	=> true,
		'popular_destination_title'		=> esc_html__( 'Popular Destination', 'travel-insight-pro' ),
		'popular_destination_sub_title' => esc_html__( 'Display the most popular places in beautiful ways', 'travel-insight-pro' ),
		'popular_destination_content_type' 	=> 'demo',
		'no_of_popular_destination' 	=> 5,
		'package_archive_title'			=> esc_html__( 'Find your next travel place', 'travel-insight-pro' ),
		'package_archive_sub_title' 	=> esc_html__( 'Display the most popular places in beautiful ways', 'travel-insight-pro' ),
		'package_search_title'			=> esc_html__( 'Find your next travel place', 'travel-insight-pro' ),
		'package_search_sub_title' 	=> esc_html__( 'Display the most popular places in beautiful ways', 'travel-insight-pro' ),

		// About Us
		'about_us_enable'				=> true,
		'about_us_content_type'			=> 'demo',
		'about_us_alignment'			=> 'align-left',
		'about_us_btn_label'			=> esc_html__( 'Read More', 'travel-insight-pro' ),
		'about_us_btn_link'				=> '#',
		'about_us_content_image'		=> get_template_directory_uri() . '/assets/uploads/about.jpg',
		'about_us_title'				=> esc_html__( 'Know about us', 'travel-insight-pro' ),
		'about_us_sub_title'			=> esc_html__( 'We do good for website to look stunning', 'travel-insight-pro' ),
		'about_us_description'			=> sprintf( '%1$s <br> %2$s', esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam in mi ut ipsum accumsan varius. Vivamus semper augue pulvinar dolor efficitur, quis auctor lorem egestas. In fermentum suscipit lectus nec tincidunt. Donec commodo arcu arcu, quis egestas libero volutpat pharetra.', 'travel-insight-pro' ), esc_html__( 'Duis nulla lectus, consequat eu ullamcorper in, vestibulum eu ante. Vivamus placerat, felis in hendrerit convallis, mauris turpis suscipit sem, eu molestie tortor erat a sem. Maecenas a ante maximus, elementum elit aliquet, tristique magna.', 'travel-insight-pro' ) ),

		// Articles
		'articles_enable'				=> true,
		'articles_content_type'			=> 'demo',
		'articles_background'			=> get_template_directory_uri() . '/assets/uploads/background-02.jpg',
		'no_of_articles_category'		=> 3,
		'no_of_articles'				=> 2,

		// Gallery
		'gallery_enable'				=> true,
		'gallery_content_type'			=> 'demo',
		'gallery_title'					=> esc_html__( 'Stunning Gallery', 'travel-insight-pro' ),
		'gallery_sub_title'				=> esc_html__( 'Show your amazing photo showcase here in Dynamic photo stream', 'travel-insight-pro' ),

		// Tours
		'tours_enable'					=> true,
		'tours_title'					=> esc_html__( 'Tour', 'travel-insight-pro' ),
		'tours_sub_title'				=> esc_html__( 'Find Tour By', 'travel-insight-pro' ),
		'tours_content_type'			=> 'demo',
		'no_of_tours'					=> 6,
		'tours_label'					=> esc_html__( 'Tour Title', 'travel-insight-pro' ),
		'tours_link'					=> '#',
		'tours_icon'					=> 'cloud',
		'tours_custom_icon_image'		=> 'icon',

		// Guide
		'guide_enable'					=> true,
		'guide_content_type'			=> 'demo',
		'no_of_guide'					=> 6,
		'guide_title'					=> esc_html__( 'Survival Guide', 'travel-insight-pro' ),
		'guide_sub_title'				=> esc_html__( 'You need following things to prepare before going for an adventure', 'travel-insight-pro' ),
		'guide_custom_icon'				=> 'drop',
		'guide_content_custom_title'	=> esc_html__( 'Guide Title', 'travel-insight-pro' ),
		'guide_content_custom_description' 	=> esc_html__( 'Proin turpis lorem, faucibus eu augue sed, pharetra porttitor...', 'travel-insight-pro' ),
		'guide_content_custom_link' 	=> '#',

		// Call To Action
		'call_to_action_enable'			=> true,
		'call_to_action_content_type'	=> 'demo',
		'call_to_action_title'			=> esc_html__( 'You are invited to relax', 'travel-insight-pro' ),
		'call_to_action_sub_title'		=> esc_html__( 'You need following things to prepare before going for an adventure', 'travel-insight-pro' ),
		'call_to_action_description'	=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam in mi ut ipsum accumsan varius. Vivamus semper augue pulvinar dolor efficitur, quis auctor lorem egestas.', 'travel-insight-pro' ),
		'call_to_action_btn_label'		=> esc_html__( 'Learn More', 'travel-insight-pro' ),
		'call_to_action_btn_link'		=> '#',
		'call_to_action_background'		=> get_template_directory_uri() . '/assets/uploads/parallax-01.jpg',

		// Counter
		'counter_enable'				=> true,
		'counter_content_type'			=> 'demo',
		'counter_title'					=> esc_html__( 'Counter Title', 'travel-insight-pro' ),
		'counter_value'					=> esc_html__( '505', 'travel-insight-pro' ),

		// Packages
		'packages_enable'				=> true,
		'packages_title'				=> esc_html__( 'Find your perfect tour', 'travel-insight-pro' ),
		'packages_sub_title'			=> esc_html__( 'Travel with best packages for an adventure', 'travel-insight-pro' ),
		'packages_content_type'			=> 'category',
		'no_of_packages'				=> 4,

		// Custom Template
		// About us Template
		'about_us_template_quote'		=> esc_html__( 'Write here something about.', 'travel-insight-pro' ),
		'about_us_template_slider_enable'	=> true,
		'about_us_template_slider_type'	=> 'custom',
		'no_of_about_us_template_slider'	=> 4,
		'about_us_template_service_enable'	=> true,
		'about_us_template_service_type'	=> 'custom',

		// Contact Us Template
		'contact_map_enable'			=> true,
		'map_content_type'				=> 'shortcode',

		// Destination Single
		'destination_content_background' => get_template_directory_uri() . '/assets/uploads/background-03.jpg',
		'related_destination_title'		=> esc_html__( 'Great Tour Around World', 'travel-insight-pro' ),
		'related_destination_sub_title'	=> esc_html__( 'Display the most beautiful places in beautiful ways', 'travel-insight-pro' ),

	);

	$output = apply_filters( 'travel_insight_pro_default_theme_options', $travel_insight_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}